# genutilities

A lib to code in python easily.

## Dependencies

- Python 3.5+

## Installation

- Install jsonutils with `pip install genutilities`
- Enjoy

## Features

- Use Json Easly

## Uncoming Features

- Json Features : clear, to_csv
- Propose in issues

## Changelog

### V 1.0.0 - XX/XX/XX (INDEV)

- First version
